@@ -1,4 +1,4 @@
-cv.olscompcomp <- function(y, x, rs = 5, tol = 1e-4, nfolds = 10, folds = NULL, seed = NULL) {
+cv.olscompcomp <- function(y, x, tol = 1e-4, nfolds = 10, folds = NULL, seed = NULL) {
 
   n <- dim(y)[1]
   ina <- 1:n
@@ -12,7 +12,7 @@ cv.olscompcomp <- function(y, x, rs = 5, tol = 1e-4, nfolds = 10, folds = NULL,
     ytrain <- y[ -folds[[ i ]], ]  ## train set dependent vars
     xtest <- x[ folds[[ i ]], -1, drop = FALSE]  ## test set independent vars
     xtrain <- x[ -folds[[ i ]], -1, drop = FALSE]  ## train set independent vars
-    est <- ols.compcomp(ytrain, xtrain, xnew = xtest)$est
+    est <- Compositional::ols.compcomp(ytrain, xtrain, xnew = xtest)$est
     ela <- abs( ytest * log( ytest / est ) )
     ela[ is.infinite(ela) ] <- NA
     kl[i] <-  2 * mean(ela, na.rm = TRUE)
